package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(``P`!````7)D$"#0````TL@```````#0`(``)
M`"@`'``;``8````T````-(`$"#2`!`@@`0``(`$```4````$`````P```%0!
M``!4@00(5($$"!,````3````!`````$````!``````````"`!`@`@`0(O*H`
M`+RJ```%`````!````$```#(K@``R#X%",@^!0AD`@``Z!(```8`````$```
M`@```-2N``#4/@4(U#X%""@!```H`0``!@````0````$````:`$``&B!!`AH
M@00(1````$0````$````!````%#E=&2PI```L"0%"+`D!0CT````]`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DR*X`
M`,@^!0C(/@4(.`$``#@!```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````"````!@```"$````$````%`````,```!'
M3E4`NJ[2X_4RM@G$$/)C2J%C,M0PJ*(E````10````@````(`````!P0!"5`
M!((X`4`!HH8!J,`!``)+*`0I.*(R1XH$#`A%````1P``````````````````
M`$D```!+````3`````````!-````3@```%````!1````4@```%,`````````
M50``````````````5@```%<```!:``````````````!;````70```%X```!@
M`````````&(```!D``````````````!F````9P```&@`````````R-6R<5GH
M[>S.WD<MH^#[2>K3[PZGW:-K+\6;MMO-XYZ'^9R!5J2;EFL)0]8Y\HL<#3J7
M"\6)!9`,%.*>B0=PTR'_Y`X+BA!7Q+F<0&I_FGRS`8MO?ZF<FV[%WQ_9<5@<
MN^.2?*Q+X\#59-1\X*<""C-BV^UZ\$IK9Z_,9D)%U>SC1\8!?4&.Q</E/RSR
MV],=^J%L8+F-\0X`````````````````````'@,`````````````$@```,0#
M`````````````!(```"&`@`````````````2````#```````````````(```
M`&4$`````````````!(```"U`P`````````````2````U@$`````````````
M$@```#D#`````````````!(```"Q`0`````````````2````)0,`````````
M````$@```,L``````````````!(```#1`0`````````````2````U0(`````
M````````$@```'(#`````````````!(```#F`@`````````````2````\@$`
M````````````$@```((#`````````````!(```!Y`P`````````````2````
MHP$`````````````$@```+\!`````````````!(```#````````````````2
M````Y`$`````````````$@```*0"`````````````!(```!^`@``````````
M```2`````@,`````````````$@```!(!`````````````!(```#S`@``````
M```````2````'@$`````````````$@```.8``````````````!(```")`P``
M```````````2````*```````````````(````+8"`````````````!(```"6
M`P`````````````2````?@``````````````$@```!`#`````````````!(`
M``#+`P`````````````2````9@(`````````````$@```/8`````````````
M`!(```!)`0`````````````2````I```````````````$@```!<#````````
M`````!(```#M`@`````````````2````PP(`````````````$@```&T"````
M`````````!(```#[`@`````````````2````90``````````````$@```-H`
M`````````````!(```!``P`````````````2````<P``````````````$@``
M`*\``````````````!(```"]`P`````````````2````"0,`````````````
M$@```%X!`````````````!(````W```````````````@````E`$`````````
M````$@```-L!`````````````!(```"=`P`````````````2````*P,`````
M````````$@```(T``````````````!(```!+```````````````@````NP(`
M````````````$@```&$#`````````````!(```!,`@`````````````2````
M3@,`````````````$@```&`"`````````````!(```#,`@`````````````2
M````60,`````````````$@```*<#`````````````!(````E`0``X)4$"```
M```2````W00``+C%!`@$````$0`/`),$``!PM`0(I0L``!(`#0#D!```,+$$
M")\!```2``T`/`0``*3%!`@`````$@`.`-\#``!`004(!````"$`&0!"!```
M4*X$"`4````2``T`PP0``##%!`AA````$@`-`#@!``"0E@0(`````!(```")
M`0``2$$%"`0````1`!D`H`0``!Q!!0@`````$``8`&L#``!$004(!````!$`
M&0"B!```'$$%"``````@`!@`W@,``$!!!0@$````(0`9`#($``"@Q00(`@``
M`!(`#0#3!```)$$%"`0````1`!@`^00``&"N!`BU`0``$@`-`'P!``!,004(
M`0```!$`&0#=`P``0$$%"`0````1`!D`V`,``'"7!`CJ`0``$@`-`!@%``#0
ML@0(1````!(`#0!3!```(+,$""0````2``T`;@0``"#$!`AW````$@`-`.X#
M```L004(`````!``&0#Z`P``L%$%"``````0`!D`E0(``+S%!`@$````$0`/
M`$(%```@P`0(]@,``!(`#0"M!```8*T$".$````2``T`I@0``%R9!`@`````
M$@`-`&P!``"PDP0(`````!(```"'!```4+`$"-@````2``T`YP,``"Q!!0@`
M````$``8`'H$```@L`0(+0```!(`#0`F!0``H,0$"$D````2``T`\00``,"L
M!`@T````$@`-``,!``!0004($P```!$`&0`&!0``4+,$"!(!```2``T`\P0`
M`/R2!`@`````$@`+``!L:6)P97)L+G-O`%])5$U?9&5R96=I<W1E<E1-0VQO
M;F5486)L90!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%])
M5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!P97)L7W!A
M<G-E`%!E<FQ?<WES7VEN:70S`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R
M;%]N97=84P!097)L7VYE=UA37V9L86=S`'!E<FQ?86QL;V,`<&5R;%]C;VYS
M=')U8W0`4&5R;%]M9U]S970`4&5R;%]G=E]F971C:'!V`%!E<FQ?;F5W4U9P
M=@!03%]M96UO<GE?=W)A<`!097)L7W-A9F5S>7-M86QL;V,`4&5R;%]A=&9O
M<FM?=6YL;V-K`%!E<FQ?871F;W)K7VQO8VL`4&5R;%]C<F]A:U]N;V-O;G1E
M>'0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`4$Q?9&]?=6YD=6UP
M`%!,7W1H<E]K97D`4&5R;%]S=E]S971P=FX`4&5R;%]S=E]S971P=@!097)L
M7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`'!E<FQ?9G)E90!P97)L7W)U
M;@!097)L7V1O=6YW:6YD`'!E<FQ?9&5S=')U8W0`;&EB;G-L+G-O+C$`;&EB
M9&PN<V\N,@!L:6)M+G-O+C8`;&EB8W)Y<'0N<V\N,0!L:6)U=&EL+G-O+C$`
M;&EB<'1H<F5A9"YS;RXP`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;W!E
M;C8T`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!R96%D`&QI8F,N<V\N-@!?
M24]?<W1D:6Y?=7-E9`!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``
M7U]S=')D=7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD
M:7(`<F5A;&QO8P!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`;65M<V5T
M`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?
M8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I
M9`!R96%D;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER
M-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C
M7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD
M`"]U<W(O;&EB+W!E<FPU+S4N,38N,B]I,S@V+6QI;G5X+71H<F5A9"UM=6QT
M:2]#3U)%`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U
M<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'!A<E]B87-E;F%M
M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A7W-T87)T`'!A<E]C
M=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`%]F
M<%]H=P!P87)?:6YI=%]E;G8`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E
M='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T-,
M14%24U1!0TL`6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N,@!'3$E"
M0U\R+C``1TQ)0D-?,BXS+C0`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXT`````@`"
M``,````"``(``@`"`````@``````!``"``(````"``(````````````%``8`
M`@````(``@````<````"``(````"``(`!@`````````"``(``@`#``(`````
M``<```````(``@````````````@`!P```````@`(``,`"``#``(``@`'````
M`0`!``$``0`"``$``0```````0`"``$``@`!``$``0````(``0`!``$``0`!
M``$``0`!``$``0````$``0`!``$``0````$``0`!``(`/`(``!`````P````
M$FEI#0``!@!8!0``$````!!I:0T```,`8@4````````!``4`BP(``!``````
M````$FEI#0``"`!8!0``$````'09:0D```<`;`4``!````!R&6D)```%`'@%
M```0````%&EI#0``!`"$!0``$````!!I:0T```(`8@4```````#\/P4(!A\`
M`$!!!0@%5P``1$$%"`50``!(004(!4X``$Q!!0@%5@``4$$%"`5H```,0`4(
M!P$``!!`!0@'`@``%$`%"`<#```80`4(!P4``!Q`!0@'!@``($`%"`<'```D
M0`4(!P@``"A`!0@'"0``+$`%"`=B```P0`4(!PH``#1`!0@'"P``.$`%"`<,
M```\0`4(!PT``$!`!0@'#@``1$`%"`</``!(0`4(!Q```$Q`!0@'$0``4$`%
M"`<2``!40`4(!Q,``%A`!0@'%```7$`%"`<5``!@0`4(!Q8``&1`!0@'%P``
M:$`%"`<8``!L0`4(!QD``'!`!0@'&@``=$`%"`<;``!X0`4(!QP``'Q`!0@'
M'0``@$`%"`<>``"$0`4(!Q\``(A`!0@'(```C$`%"`<A``"00`4(!R(``)1`
M!0@'(P``F$`%"`<D``"<0`4(!R4``*!`!0@')@``I$`%"`<G``"H0`4(!R@`
M`*Q`!0@'*0``L$`%"`<J``"T0`4(!RL``+A`!0@'10``O$`%"`<L``#`0`4(
M!RT``,1`!0@'+@``R$`%"`<O``#,0`4(!S```-!`!0@',0``U$`%"`<R``#8
M0`4(!S,``-Q`!0@'-```X$`%"`<U``#D0`4(!TT``.A`!0@'-P``[$`%"`<X
M``#P0`4(!SD``/1`!0@'.@``^$`%"`<[``#\0`4(!ST```!!!0@'/@``!$$%
M"`<_```(004(!T````Q!!0@'00``$$$%"`="```4004(!T,``!A!!0@'1```
M4X/L".A[!@``@</[K```BX/\____A<!T!>CV`0``@\0(6\,`_S4$0`4(_R4(
M0`4(`````/\E#$`%"&@`````Z>#_____)1!`!0AH"````.G0_____R440`4(
M:!````#IP/____\E&$`%"&@8````Z;#_____)1Q`!0AH(````.F@_____R4@
M0`4(:"@```#ID/____\E)$`%"&@P````Z8#_____)2A`!0AH.````.EP____
M_R4L0`4(:$````#I8/____\E,$`%"&A(````Z5#_____)31`!0AH4````.E`
M_____R4X0`4(:%@```#I,/____\E/$`%"&A@````Z2#_____)4!`!0AH:```
M`.D0_____R5$0`4(:'````#I`/____\E2$`%"&AX````Z?#^____)4Q`!0AH
M@````.G@_O___R500`4(:(@```#IT/[___\E5$`%"&B0````Z<#^____)5A`
M!0AHF````.FP_O___R5<0`4(:*````#IH/[___\E8$`%"&BH````Z9#^____
M)61`!0AHL````.F`_O___R5H0`4(:+@```#I</[___\E;$`%"&C`````Z6#^
M____)7!`!0AHR````.E0_O___R5T0`4(:-````#I0/[___\E>$`%"&C8````
MZ3#^____)7Q`!0AHX````.D@_O___R6`0`4(:.@```#I$/[___\EA$`%"&CP
M````Z0#^____)8A`!0AH^````.GP_?___R6,0`4(:``!``#IX/W___\ED$`%
M"&@(`0``Z=#]____)91`!0AH$`$``.G`_?___R680`4(:!@!``#IL/W___\E
MG$`%"&@@`0``Z:#]____):!`!0AH*`$``.F0_?___R6D0`4(:#`!``#I@/W_
M__\EJ$`%"&@X`0``Z7#]____):Q`!0AH0`$``.E@_?___R6P0`4(:$@!``#I
M4/W___\EM$`%"&A0`0``Z4#]____);A`!0AH6`$``.DP_?___R6\0`4(:&`!
M``#I(/W___\EP$`%"&AH`0``Z1#]____)<1`!0AH<`$``.D`_?___R7(0`4(
M:'@!``#I\/S___\ES$`%"&B``0``Z>#\____)=!`!0AHB`$``.G0_/___R74
M0`4(:)`!``#IP/S___\EV$`%"&B8`0``Z;#\____)=Q`!0AHH`$``.F@_/__
M_R7@0`4(:*@!``#ID/S___\EY$`%"&BP`0``Z8#\____)>A`!0AHN`$``.EP
M_/___R7L0`4(:,`!``#I8/S___\E\$`%"&C(`0``Z5#\____)?1`!0AHT`$`
M`.E`_/___R7X0`4(:-@!``#I,/S___\E_$`%"&C@`0``Z2#\____)0!!!0AH
MZ`$``.D0_/___R4$004(:/`!``#I`/S___\E"$$%"&CX`0``Z?#[____)0Q!
M!0AH``(``.G@^____R40004(:`@"``#IT/O___\E%$$%"&@0`@``Z<#[____
M)1A!!0AH&`(``.FP^___58GE5E.#Y/"#[#"-11")1"0(C44,B40D!(U%"(D$
M).BL_?__QT0D"."5!`C'1"0$X)4$",<$))"6!`CH0"T``(`]3$$%"`!U+NBR
M_/__A<"CK%$%"`^$@P$``(D$).C]^___H4A!!0B)!"3H,/___\:`YP(```"A
M2$$%"(D$).@<____@(@O`P```J%(004(B00DZ`C___^+30@QTH/!!8"(+P,`
M``&)3"0HB50D+-]L)"C8!:`D!0C=!:@D!0C9R=KIW^">#X?^````P>$"B0PD
MZ'G\__^+=0R+70C'!:11!0@$````BQ:#^P&CH%$%",=`!*7'!`B)$(L5)$$%
M",=`#*C'!`B)4`BZ`0```'X5C;0F`````(L,EHE,D`R#P@$YVG7R@\,#QP28
M`````(E$)`RAK%$%"(E<)`C'1"00`````,=$)`0`K00(B00DZ'O]__^%P(G#
M=#:AK%$%"(D$).A(^___N&G&!`CH'@T``(7`="RAK%$%"(D$).CM^O__Z!C]
M__^-9?B)V%M>7<.AK%$%"(D$).BB_?__B</KN:&H404(A<!T"HD$).C]*@``
MZ\&X'L8$".C1#```A<"CJ%$%"'2NZ^''1"0$4$$%",<$)!G&!`CH0OS__\<$
M)`$```#HQOO__V:0,>U>B>&#Y/!05%)HH,4$"&@PQ00(459H<)<$".CC^___
M]&:0BQPDPV:09I!FD&:09I!FD+@O004(+2Q!!0B#^`9W`O/#N`````"%P'3U
M58GE@^P8QP0D+$$%"/_0R<.0C70F`+@L004(+2Q!!0C!^`*)PL'J'P'0T?AU
M`O/#N@````"%TG3U58GE@^P8B40D!,<$)"Q!!0C_TLG#D(VT)@````"`/61!
M!0@`=1-5B>6#[`CH?/___\8%9$$%"`')\\-FD*'0/@4(A<!T'K@`````A<!T
M%56)Y8/L&,<$)-`^!0C_T,GI>?___^ET____9I!FD%6)P5>#P1Q64X'L6`$`
M`(E$)!0QP(UV`(L4@0_*B52$&(/``8/X$'7OC50D3(V,)$P!``"-="8`BT+L
M,P(S0M0S0LS!R!^)0@R#P@0YRG7HBT0D%(M4)!B+`(E$)!"+1"04BUPD$(M`
M!(E$)`R+1"04BTPD#(M`",'!'B'+B40D"(M$)!2+0`R)1"0$BT0D%(M`$`'"
MB00DBT0D$,'`!8V\`IEY@EJ+1"0,BU0D""-4)`SWT"-$)`0)T(M4)`0!QXM$
M)!`#5"0<B?WWT"-$)`@)V(M<)`B-M`*9>8):B?B+5"00P<`%`<8#7"0@B?#!
MP`7!PAZ-G`.9>8):B?CWT"'5(<@)Z(GU`<.)\,'''O?0`TPD)"'](=`)Z(G=
MC8P!F7F"6HG8P<`%`<$#5"0HB<C!P`7!QAZ-E`*9>8):B=CWT"'U(?@)Z(G-
M`<*)R,'#'O?0`WPD+"'=(?`)Z(G5C;P'F7F"6HG0P<`%`<<#="0PB?C!P`7!
MP1Z-M`:9>8):B=#WT"'-(=@)Z(G]`<:)^,'"'O?0`UPD-"'5(<@)Z(GUC9P#
MF7F"6HGPP<`%`<,#3"0XB=C!P`7!QQZ-C`&9>8):B?#WT"'](=`)Z(G=`<&)
MV,'&'O?0`U0D/"'U(?@)Z(G-C90"F7F"6HG(P<`%`<(#?"1`B=#!P`7!PQZ-
MO`>9>8):B<CWT"'=(?`)Z(G5`<>)T,'!'O?0`W0D1"'-(=@)Z(G]C;0&F7F"
M6HGXP<`%`<8#7"1(B?#!P`7!PAZ-G`.9>8):B?CWT"'5(<@)Z(GU`<.)\,''
M'O?0`TPD3"'](=`)Z(G=C8P!F7F"6HG8P<`%`<$#5"10B<C!QA[!P`4A]8V4
M`IEY@EJ)V/?0(?@)Z(G-`<*)R,'#'O?0`WPD5"'=(?`)Z(G5C;P'F7F"6HG0
MP<`%`<<#="18B?C!P`7!P1Z-M`:9>8):B=#WT"'-(=@)Z(G]`<:)^,'"'O?0
M`UPD7"'5(<@)Z(GUC9P#F7F"6HGPP<`%`<,#3"1@B=C!P`7!QQZ-C`&9>8):
MB?#WT"'](=`)Z(G=`<&)V,'&'O?0`U0D9"'U(?@)Z(V4`IEY@EJ)R,'#'L'`
M!0'"B=@#?"1H,?`QR,'!'HV\!Z'KV6Z)T,'`!0'XB<\#="1L,=\QU\'"'HV\
M/J'KV6Z)QL'&!0'^B=<#7"1P,<\QQ\'`'HV\.Z'KV6Z)\\'#!0'[B<<#3"1T
M,=<Q]\'&'HV\.:'KV6Z)V<'!!0'YB?<#5"1X,<<QW\'#'HV\.J'KV6Z)RL'"
M!0'ZB=\#1"1\,?<QS\'!'HV\.*'KV6Z)T,'`!0'XB<\#M"2`````,=\QU\'"
M'HV\/J'KV6Z)QL'&!0'^B=<#G"2$````,<\QQ\'`'HV\.Z'KV6Z)\\'#!0'[
MB<<#C"2(````,=<Q]\'&'HV\.:'KV6Z)V<'!!0'YB?<#E"2,````,<<QWXV\
M.J'KV6Z)RL'"!0'ZP<,>`X0DD````(G?,?<QSXV\.*'KV6Z)T,'!'L'`!0'X
MB<\#M"24````,=\QU\'"'HV\/J'KV6Z)QL'&!0'^B=<#G"28````,<\QQ\'`
M'HV\.Z'KV6Z)\\'#!0'[B<<#C"2<````,=<Q]\'&'HV\.:'KV6Z)V<'!!0'Y
MB?<#E"2@````,<<QW\'#'HV\.J'KV6Z)RL'"!0'ZB=\#A"2D````,?<QS\'!
M'HV\.*'KV6Z)T,'`!0'XB<\#M"2H````,=\QU\'"'HV\/J'KV6Z)QL'&!0'^
MB=<#G"2L````,<\QQ\'`'HV\.Z'KV6Z)\\'#!0'[B<<#C"2P````,=<Q]\'&
M'HV\.:'KV6Z)V<'!!0'YB?<#E"2T````,<<QW\'#'HV\.J'KV6Z)RL'"!8G=
M`?J+O"2X````(?4!QXG8"?`AR`GHC;P'W+P;CXG0P<`%`?B+O"2\````P<$>
MB<TAW0'WB<X)WB'6">Z-O#?<O!N/B<;!Q@4!_HN\),````#!PAZ)U2'-`=^)
MTPG+(<,)ZXV\']R\&X^)\\'#!0'[B[PDQ````,'`'HG%(=4!SXG!"=$A\0GI
MC;P/W+P;CXG9P<$%`?F+O"3(````P<8>B?4AQ0'7B?()PB':">J-O!?<O!N/
MB<K!P@4!^HN\),P```#!PQZ)W2'U`<>)V`GP(<@)Z(V\!]R\&X^)T,'`!0'X
MB[PDT````,'!'HG-(=T!]XG."=XAU@GNC;PWW+P;CXG&P<8%`?Z+O"34````
MP<(>B=4AS0'?B=,)RR'#">N-O!_<O!N/B?/!PP4!^XN\)-@```#!P!Z)Q2'5
M`<^)P0G1(?$)Z8V\#]R\&X^)V<'!!0'YB[PDW````,'&'HGU(<4!UXGR"<(A
MV@GJC;P7W+P;CXG*P<(%`?J+O"3@````P<,>B=TA]0''B=@)\"'(">B-O`?<
MO!N/B=#!P`4!^(N\).0```#!P1Z)S2'=`?>)S@G>(=8)[HV\-]R\&X^)QL'&
M!0'^B[PDZ````,'"'HG5(<T!WXG3"<LAPPGKC;P?W+P;CXGSP<,%`?N+O"3L
M````P<`>B<4AU0'/B<$)T2'Q">F-O`_<O!N/B=G!P04!^8N\)/````#!QAZ)
M]2'%`=>)\@G"(=H)ZHV\%]R\&X^)RL'"!0'ZB[PD]````,'#'HG=(?4!QXG8
M"?`AR`GHC;P'W+P;CXG0P<`%`?B+O"3X````P<$>B<TAW0'WB<X)WB'6">Z-
MO#?<O!N/B<;!Q@4!_HN\)/P```#!PAZ)U0'?B=,)RR'-(<,)ZXV\']R\&X^)
M\\'#!0'[B[PD``$``,'`'HG%(=4!SXG!"=$A\0GIC;P/W+P;CXG9P<$%`?F+
MO"0$`0``P<8>B?4AQ0'7B?()PB':">J-O!?<O!N/B<K!PQ[!P@4!UXG:`X0D
M"`$``#'R,<K!P1Z-E!#6P6+*B?C!P`4!T(G*`[0D#`$``#':,?J-M!;6P6+*
MB<+!P@4!\HG^P<8>`YPD$`$``(GW,<\QQXV\.];!8LJ)T\'`'L'#!0'[B<<#
MC"04`0``,?<QU\'"'HV\.=;!8LJ)V<'!!0'/B=$#M"08`0``,<$QV<'#'HVT
M#M;!8LJ)^<'!!0'.B=D#A"0<`0``,=$Q^0.4)"`!``"-C`C6P6+*B?#!P`4!
MP8GXP<`>B<<QWS'WC;PZUL%BRHG*P<8>P<(%`=>)\@.<)"0!```QPC'*P<$>
MC9P3UL%BRHGZP<(%`=J)RP.$)"@!```Q\S'[P<<>C9P8UL%BRHG0P<`%`<.)
M^`.T)"P!```QR#'0P<(>C;0&UL%BRHG8P<`%`?")U@.,)#`!```Q_C'>P<,>
MC;0QUL%BRHG!P<$%`<Z)V0.\)#0!```QT3'!P<`>C;P/UL%BRHGQP<$%`?F)
MQP.4)#@!```QWS'WC;PZUL%BRHG*P<(%P<8>`=<#G"0\`0``B?(QPC'*C9P3
MUL%BRHGZP<$>P<(%`=J)RP.$)$`!```Q\S'[P<<>C9P8UL%BRHG0P<`%`<.)
M^`.T)$0!```QR#'0P<(>C;0&UL%BRHG8P<`%`?")U@.,)$@!```Q_C'>P<,>
MC;0QUL%BRHG!P<$%`?&)W@.\)$P!```QUC'&P<`>C;PWUL%BRHG.P<8%`?Z)
MQP.4)%`!```QWS'/P<$>C;PZUL%BRHGRP<(%`?J+?"00`[PD5`$``(V\.];!
M8LJ)RS'#,?,!^XG7P<<%`?N+?"04P<8>B1\#5"0,`TPD!`,$)(E7!(M4)`B)
M3PR)1Q`!\HE7"('$6`$``%M>7UW#C;0F`````%575HG&4X/L+(7`B50D''1+
MH4!!!0B%P(E$)!AT/@^V!CP]=4,QVXM$)!B+*(7M="N)QY"-="8`B5PD"(ET
M)`2)+"3H2/'__X7`=0>`?!T`/70M@\<$BR^%[77<@\0L,<!;7E]=PV:0A,!T
MN8GS@\,!#[8#/#UT!(3`=?(I\^NGBT0D'(GY*TPD&,'Y`HD(@\0LC40=`5M>
M7UW#D(UT)@"#[!R-5"0,Z%3___^#Q!S#4XG#@^P8C50D#(G8Z#____^%P'0V
MC78`H4!!!0B+5"0,C120BTH$A<F)"G39C78`@\($BTH$A<F)"G7TC50D#(G8
MZ`G___^%P'7-@\086\-64X/L%*%(004(B00DZ)[P__^+@'`!``"+<`2A2$$%
M"(D$).B(\/__#[:8Y`(``*%(004(@^-_B00DZ''P__^+0`0/MT`0P>`'"=AF
MB48"H4A!!0B)!"3H5/#__XN`<`$``(M8!*%(004(B00DZ#[P___'1"0(````
M`,=$)`2?QP0(B00DZ);N__^)0QRA2$$%"(D$).@6\/__BX!P`0``BU@$H4A!
M!0B)!"3H`/#__XN`Y`,``(E#(*%(004(B00DZ.KO__^+@'`!``"+6`2A2$$%
M"(D$).C4[___,=*+@'`&``"%P'06H4A!!0B)!"3HN^___XN`<`8``(M0<*%(
M004(B5,DB00DZ*+O__^+@'`!``"+0`3'0"@`````H4A!!0B)!"3HA>___XN`
M<`$``(M`!,=`&`````"A2$$%"(D$).AH[___BX!P`0``BU@$H4A!!0B)!"3H
M4N___XN`>`$``(E#+(/$%%M>PXUV`('LK````(7`B;0DH````(G&B9PDG```
M`(F\)*0```")K"2H````=`6`.`!U(XN<))P```"+M"2@````B[PDI````(NL
M)*@```"!Q*P```##B00DZ"CO__^%P(G'=,^)/"3HBN[__X7`B<,/A+````"`
M>Q,N#X2^````B30DC6L3Z/OL__^)+"2)1"0LZ._L__^+3"0LC40!`HD$).AO
M[/__B6PD%(ET)!#'1"0,P,4$",=$)`C_____QT0D!`$```")!"2)P^C%[O__
MC40D,(E$)`B)7"0$QP0D`P```.A-[O__@_C_=!"+1"1`)0#P```]`$```'1H
MB1PDZ$#K__^)'"3HJ.K__XD\).C@[?__A<")PP^%5O___XVV`````(D\).A(
M[O__B30DZ,#J___I^/[__XUV``^V0Q2$P`^$&O___SPN#X4N____@'L5``^$
M"/___^D?____D(UT)@")V.B9_O__ZY>-M"8`````55>)QU8QP%.)TX/L/(`Z
M/0^4P`'#B1PDZ//K__^-5"0LB<6)^.CV^___A<")Q@^$U````(D$).C4Z___
M.<4/AJ0```"+3"0LP>$"#[8'/#T/A&H!``"$P`^$8@$``(GXZPJ-M@````"$
MTG0+@\`!#[80@/H]=?$I^(LU0$$%"(U$*`*)!"0!SN@3Z___A<")!@^$/`$`
M`*%`004(BU0D+(L$D.L+C78`@/H]=`^#P`$/MA>#QP&$TH@0=>S&`#TQTHVT
M)@`````/M@P3B$P0`8/"`83)=?$QP(/$/%M>7UW#C;0F``````^V`X/#`8@&
M@\8!A,!TX`^V`X/#`8@&@\8!A,!UXNO/BQ5`004(BP*%P`^$KP```#'VC;8`
M````@\8!BP2RA<!U]HT$M0@```"+#8!!!0B%R70UB40D!(D4).A)ZO__A<")
M1"0<HT!!!0AT?XT,M0````"+1"0<QT2P!`````")="0LZ=O^__^)!"2)5"08
MQP6`004(`0```.@:ZO__BU0D&(7`B40D''1!C0RU`````(E,)`B)5"0$B00D
MB4PD&.B#Z/__BT0D'(M,)!BC0$$%".N?C70F`#'`Z;+^__^X"````#'VZ5[_
M__^X_____^G\_O__C78`@>P\$```B;0D,!```(UT)!S'1"0(_P\``(ET)`3'
M!"3&Q00(B;PD-!```(G'B:PD.!```(G59:$4````B80D'!```#'`B9PD+!``
M`.C/Z/__A<`/CH<```"-6/^`?!P<`'1UB<.)7"0(QT0D!"\```")-"3H9^K_
M_X7`=&.A2$$%"(D$).AFZ___B5PD#(ET)`B)?"0$B00DZ.+J__^+A"0<$```
M93,%%````'51BYPD+!```(NT)#`0``"+O"0T$```BZPD.!```('$/!```,.-
MM"8`````A=MUB8UT)@"A2$$%"(D$).@#Z___B6PD"(E\)`2)!"3H,^C__^N?
MZ,SG__^-M@````"-OP````!3B<.#[!BA2$$%"(D$).C-ZO__B5PD!,<$)`,`
M``"#P%R)1"0(Z,;J__^%P'0*@\08,<!;PXUV`*%(004(B00DZ)OJ__^+0&PE
M`/```#T`0```=!RA2$$%"(D$).A_ZO__BT!L)0#P```]`*```'6^B1PDQT0D
M!`(```#HL.G__X7`#Y3`@\08#[;`6\.-=@"#[!RA2$$%"(D$).A`ZO__QT0D
M#-7%!`C'1"0(L),$",=$)`3?Q00(B00DZ+#H__^#Q!S#C;8`````C;\`````
M@^PLH4A!!0B)!"3H`.K__XD$).BH____H4A!!0B)!"3HZ^G__\=$)!0`````
MQT0D$)_'!`C'1"0,G\<$",=$)`@@P`0(QT0D!/O%!`B)!"3H^^C__X/$+,.-
MM"8`````@>P\(```B9PD,"```(U<)"IEH10```")A"0L(```,<")M"0T(```
MB;PD."```.@=Y___QT0D%-'%!`C'1"0,$,8$",=$)`@!$```QT0D!`$```")
M'"2)1"00Z*'I__^%P'AUC;PD*Q```,=$)`@`$```B7PD!(D<).ABYO__A<")
MQGA4C4`!B00DZ/'F__^%P(G#=$.)="0(B7PD!(D$).B+Y?__Q@0S`(N4)"P@
M``!E,Q44````B=AU(8N<)#`@``"+M"0T(```B[PD."```('$/"```,.0,=OK
MS>BOY?__ZPV0D)"0D)"0D)"0D)"0Z0O___^-="8`C;PG`````%575E.![$P0
M``!EH10```")A"0\$```,<"X'L8$"(NT)&`0``"+O"1D$```Z&_W___'1"0$
M+P```(DT)(G#Z(WF__^%P'0MB?*X)\8$".B-^O__BY0D/!```&4S%10```")
M\`^%1P$``('$3!```%M>7UW#B30DZ'3F__^)/"2-?"0\QT0D!#3&!`B)1"0L
MZ'SG__^)Q6:0A>UTJX!]``!U!;T<Q@0(A=MT%(EL)`2)'"3H*>3__X7`#X2G
M````B2PDZ"GF__^`?`7_+W419I"#Z`&`?`7_+\9$!0``=/&+5"0LC400`3W_
M#P``#X]5____B70D&,=$)!0VQ@0(B6PD$,=$)`Q:QP0(QT0D"``0``#'1"0$
M`0```(D\).C>Y___H4A!!0B)!"3H@>?__XE\)`3'!"0#````@\!<B40D".A:
MY___A<!U'*%(004(B00DZ%GG__^+0&PE`/```#T`@```=!O'1"0$-,8$",<$
M)`````#HEN;__XG%Z1?____'1"0$`0```(D\).AOYO__A<!UT8GZN"?&!`CH
M/_G__XD\).C'Y?__B<;IH_[__^C;X___C70F`(V\)P````"+1"0$#[8(A,ET
M((U0`>L*#[8*@\(!A,ET$8#Y+W7Q#[8*B="#P@&$R77O\\.-=@!3@^P8BUPD
M((7;=#R`.P!T-XD<).CGY/__C40#_SG#<@[K49"-="8`@^@!.=AT"8`X+W3T
MZS=FD(`X+Y"-="8`#X6!````9I#'!"0"````Z#SD__^%P'1H9L<`+@"#Q!A;
MPXVV`````(`X+W0'@^@!.<-R]#G8=,"#Z`$YPW,%@#@O=/0IV(U0`H'Z`!``
M`'<O@\`!B5PD!,=$)`P`$```B40D",<$)*!!!0CH,.7__X/$&+B@004(6\.-
MM@````"#Q!@QP%O#QT0D(#;&!`B#Q!A;Z:CD__^0C;0F`````%=6@^PT9:$4
M````B40D+#'`H:S'!`B)1"0*H;#'!`B)1"0.H;3'!`B)1"02H;C'!`B)1"06
MH;S'!`B)1"0:H<#'!`B)1"0>H<3'!`B)1"0BH<C'!`B)1"0F#[<%S,<$"&:)
M1"0JN#C&!`CH<?3__[A!Q@0(Z&?T__^X2<8$".A=]/__N%+&!`CH4_3__[A9
MQ@0(Z$GT__^X:<8$".@_]/__N![&!`CH-?3__[AUQ@0(Z"OT__^X?\8$".@A
M]/__N(G&!`CH%_3__[@GQ@0(Z`WT__^XD\8$".@#]/__N)S&!`CH^?/__[BG
MQ@0(Z-_S__^%P'0,B<*X?\8$".@/]___N+C&!`CHQ?/__X7`=`R)PKC*Q@0(
MZ/7V__^XU<8$".BK\___A<!T+XG"N![&!`CHV_;__[H!QP0(N%G&!`CHS/;_
M_XM$)"QE,P44````=4F#Q#1>7\.0N.7&!`CH;O/__X7`=!*)PKAUQ@0(Z)[V
M___KP8UT)@"-="0;O_;&!`BY"@```/.F=:N-5"0EN'7&!`CH>/;__^N;Z"'A
M__^0H2A!!0B#^/]T!O/#C70F`(/L#+AUQ@0(Z!/S__^%P'0?#[80,<"$TG0(
M,<"`^C`/E<"C*$$%"(/$#,.0C70F`#'`Z^Z-M@````"-OP````"#[!SHV.#_
M_XD$).@PX/__A<!T#(L`@\0<PXVV`````#'`Z_*-M@````"-OP````!55[\-
MQP0(5E.[`\<$"(/L7,=$)#0-QP0(C70D/,=$)#@#QP0(QT0D/!#'!`C'1"1`
M!L<$",=$)$0+QP0(QT0D2!W'!`C'1"1,`````.LBD(M$)'")+"2)1"0$Z(#?
M__^%P'0\A=MT*HL&B=^#Q@2)PXGXZ#CR__^%P(G%=`6`.`!US8M4)'")^.AB
M]?__A=MUUH/$7%M>7UW#C;8`````BT0D<(D$).A4X?__B2PDB40D+.A(X?__
MBU0D+(U$`@*)!"3HR.#__XEL)!C'1"04-,8$",=$)`Q:QP0(QT0D"/_____'
M1"0$`0```(G"BT0D<(D4)(E4)"R)1"00Z`[C__^+5"0LB?CHX_3__^E2____
MC;0F`````(V\)P````!55U93@>P\@0``9:$4````B80D+($``#'`N![&!`B+
MK"10@0``QT0D7#3'!`C'1"1@',8$",=$)&0`````QT0D=,K&!`C'1"1XP\8$
M",=$)'PYQP0(QX0D@````.#&!`C'A"2$````0<<$",>$)(@`````````QT0D
M:"C'!`C'1"1L1<<$",=$)'``````Z/WP__^%P'0)@#@`#X5@!```Z`O^__^%
MP(G##X1R!```B1PDZ"G@__^-1``!B00DZ*W?__^`.P")QG0XB<>-="8`#[8#
M@\,!B3PD@\<"QT0D#$['!`C'1"0(_____XE$)!#'1"0$`0```.CSX?__@#L`
M=<Z-?"1XN,K&!`CK#8UV`(/'!(M'_(7`="[H<?#__X7`B<-TZX`X`'3FZ)'V
M__^%P'3=B1PDZ"7@__^%P(G!=5&-M"8`````BUPD7(7;=$"`.P"_`0```'46
MZS2-="8`BUR\7(7;="B#QP&`.P!T((G8Z$GV__^%P'3EB1PDZ-W?__^%P'39
MB<'K!Y"-="8`,<F)#"2)\XE,)#SH0-___XM,)#R+.X/#!(V7__[^_O?7(?J!
MXH"`@(!TZ??"@(```'4&P>H0@\,"`-*#VP,I\XV<`P0$``")'"2)3"0\Z(W>
M__^+3"0\B70D',=$)!A3QP0(QT0D%#;&!`B)3"00QT0D#%C'!`C'1"0(____
M_\=$)`0!````B00DB40D0.C-X/__BT0D0,=$)`3``0``B00DZ!G?__^#^/\/
MA(@```"A2$$%"(D$).A3X/__QP0D`P```(/`7(E$)`B+1"1`B40D!.A(X/__
MA<`/A*@```"+1"1`B40D$(M%`,=$)`@,R`0(QT0D!`$```")1"0,H41!!0B)
M!"3HQ-___\=$)$0`````BY0D+($``&4S%10```"+1"1$#X7D"```@<0\@0``
M6UY?7<.0Z+/>__^+`(/X$0^$:/___XE$)!2+1"1`B40D$(M%`,=$)`C0QP0(
MQT0D!`$```")1"0,H41!!0B)!"3H6-___\=$)$0`````ZY*-M@````"A2$$%
M"(D$).A[W___BT!L)0#P```]`$````^%./___Z%(004(B00DZ%O?__^+<'3H
M0]S__SG&#X4;____H4A!!0B)!"3H/M___XM`;"7_`0``/<`!```/A?O^__^)
M'"3H\]S__XE$)$2X!L<$".@%[O__A<`/A-4!``")!"3HQ=W__XE$)`2+10")
M!"3H1O;__X7`B<,/A+0!``")'"3H)-W__X/X`WXGC70#_+]AQP0(N04```#S
MIG45@_@$#X2S!@``@'P#^R\/A*@&``"0Z'/Z__^%P'4<QT0D!`````")'"3H
M_]S__X7`B40D3`^%8P$``+H!QP0(N'7&!`CHM/#__S';Z!W<___'1"0<G\<$
M",=$)!0VQ@0(QT0D#'K'!`C'1"0(_____\=$)`0!````B40D&(M$)$")1"00
MBT0D1(D$).B-WO__BW0D1(M\)$#K48UV`.@+W?__@S@1=5GHP=O__X/#`<=$
M)""?QP0(B5PD',=$)!0VQ@0(B7PD$,=$)`R(QP0(B40D&,=$)`C_____QT0D
M!`$```")-"3H,M[__\=$)`3``0``B30DZ(+<__^#^/]TG8M$)$")!"3H,=K_
M_XM4)$2X'L8$".CC[___BT0D1(D$).CG^?__Z:;]__]FD(D$)(E$)#SHU/G_
M_XM$)#R)!"3H2-S__XE$)$3I@_W__[X!````N"C'!`CK#HUV`(M$M&B#Q@&%
MP'0AZ%#L__^%P'3L@#@`=.>)!"3H#]S__X7`=-N)P^E3^___L`V[+<<$".E3
M^___BUT`Z43^___'1"0,`@```,=$)`3N____QT0D"/____^)!"3HH-K__XM$
M)$R-E"0L`0``QT0D"`8```")5"0$B00DZ#'9__^`O"0L`0```'4.@+PD+0$`
M`$,/A$8%``"+1"1,QT0D#`````#'1"0$`````,=$)`@`````B00DZ$7:___'
MA"3,`````2-%9\>$)-````")J\WOQX0DU````/[<NIC'A"38````=E0R$,>$
M)-P```#PX=+#QX0DX`````````#'A"3D`````````,>$)"@!````````D(UT
M)@"+1"1,C90D+`$``,=$)`@`@```B50D!(D$).AYV/__A<")Q0^.PP$``(N4
M).````"-!.HYT`^2P@^VTHF$).````")Z`&4).0```#!Z!T!A"3D````BX0D
M*`$``(7`#X1\`0``ND````")[BG".=5^`HG6C80$Z````(V4)"P!``")="0(
MB50D!(D$).A'V/__BX0D*`$```'P@_A`B80D*`$```^%5O___XV$)"P!```I
M]0'&C80DS````.C7WO__C;0F`````(/]/P^.X@```(/M0(GWB>K!Z@:)T,'@
M!HE4)$B-7`9`BP>)A"3H````BT<$B80D[````(M'"(F$)/````"+1PR)A"3T
M````BT<0B80D^````(M'%(F$)/P```"+1QB)A"0``0``BT<<B80D!`$``(M'
M((F$)`@!``"+1R2)A"0,`0``BT<HB80D$`$``(M'+(F$)!0!``"+1S")A"08
M`0``BT<TB80D'`$``(M'.(F$)"`!``"+1SR#QT")A"0D`0``C80DS````.@"
MWO__.=\/A4K___^+1"1(BWPD2(/``<'@!L'G!@'&*?V-A"3H````QT0D#$0`
M``");"0(B70D!(D$).AVV/__B:PD*`$``.DB_O__9I"-M"0L`0``Z=S^__^+
M1"1,B00DZ(#:__^+G"3@````B[0DY````(G8P>@#@^`_C5`!@_HXQH0$Z```
M`(`/CUX"``"Z-P```"G"C80$Z0```(E4)`C'1"0$`````(D$).BTV/__B?")
M\L'H&(B$)"`!``")\,'H$(B$)"$!``")\,'H"(B$)"(!``")V,'H&(B$)"0!
M``")V,'H$(B$)"4!``")V,'H"(B$)"8!``"-A"3,````B)0D(P$``(VT)*,`
M``"(G"0G`0``B??HY]S__XN4),P```"-K"20````C9PDRP```(G1P>D8#[;!
MB(PDCP```(G1P>D0B(PDD````(G1B)0DD@```(N4)-````#!Z0B(C"21````
MB='!Z1B(C"23````B='!Z1"(C"24````B=&(E"26````BY0DU````,'I"(B,
M))4```")T<'I&(B,))<```")T<'I$(B,))@```")T8B4))H```"+E"38````
MP>D(B(PDF0```(G1P>D8B(PDFP```(G1P>D0B(PDG````(G1B)0DG@```(N4
M)-P```#!Z0B(C"2=````B='!Z1B(C"2?````B='!Z1"(C"2@````B='!Z0B(
MC"2A````B)0DH@```.D.````C;0F``````^V10"#Q0&)/"2#QP*)1"00QT0D
M#$['!`C'1"0(_____\=$)`0!````Z++8__\YWW7.QH0DRP````#'1"0<G\<$
M"(ET)!B+1"1`QT0D%#;&!`C'1"0,:\<$",=$)`C_____B40D$(M$)$3'1"0$
M`0```(D$).AFV/__Z43Z__^+;02%[0^$3OG__XDL).@^UO__@_@##X8]^?__
MC70%_+]FQP0(N04```#SI@^%)_G__XGKZ2#Y__^Z/P```"G"C80$Z0```(E4
M)`C'1"0$`````(D$).A6UO__C80DS````.CJVO__C90DZ````+D.````,<")
MU_.KZ7_]__^`O"0N`0``00^%K/K__X"\)"\!``!##X6>^O__@+PD,`$``$@/
MA9#Z__^`O"0Q`0``10^%@OK__XM$)$S'1"0,`@```,=$)`3&____QT0D"/__
M__^)!"3HQ]3__XM$)$R-E"0L`0``B50D!,=$)`@I````B00DZ%C3__^-E"0L
M`0``QT0D')_'!`B)5"08Z;;^___HV]/__XUT)@"-O"<`````55=64X/L'*%(
M004(B00DZ-S6___&@.4"```!N%G&!`CHN^7__X7`=`F`.#$/A)8"``#HV?#_
M_Z%(004(B00DZ*S6___'1"0,"P```,=$)`@!````QT0D!)G'!`B)!"3H;-3_
M_X7`#X2\````BT`,@SVD404(`8MX&`^.J0```#'VNP$```#K*HM%#(E$)`2A
MH%$%"(L$F(D$).B!TO__A<!U=:&D404(@\,!@\8!.=A^:Z%(004(B00DZ#'6
M___'1"0,`````(ET)`B)?"0$B00DZ(G5__^%P'0]BRCV10D$=:6A2$$%"(D$
M).@`UO__QT0D#`(```#'1"0(`````(EL)`2)!"3H--/__^EZ____C;0F````
M`*&D404(C5#_.?(/A$`!``"A2$$%"(D$).B[U?__QT0D#`0```#'1"0(`0``
M`,=$)`2>QP0(B00DZ'O3__^%P(G#=#6+0`R+,*%(004(B00DZ(/5___'1"0(
MH,<$"(ET)`2)!"3HK]+__XM##(L8]D,*0`^%&`$``*%(004(B00DZ%/5___'
M1"0,!````,=$)`@!````QT0D!*7&!`B)!"3H$]/__X7`B<9T-K@GQ@0(Z!/D
M__^%P(G##X1Q`0``BT8,BSBA2$$%"(D$).@'U?__B5PD"(E\)`2)!"3H-]+_
M_Z%(004(B00DZ.K4___&@.4"````H4A!!0B)!"3HUM3__\>`8`0```````"X
M'L8$".BRX___A<")PZ.H404(#X2;````QT0D!,`!``")!"3H4]/__X/X$70-
MA<!T"8/X_P^%>`$``(/$'%M>7UW#D(/X`0^.M_[__[L!````9I"A2$$%"(/#
M`8D$).AHU/__B7PD!(D$).CLT/__.1VD404(?]SIA_[__XVT)@````"A2$$%
M"(D$).@[U/__B5PD!(D$).@_T___Z<K^__]FD(!X`0`/A&7]___I6_W__Y"A
MH%$%"(D$).AK\?__A<"CJ%$%"`^$V0```(M&#(L]H%$%"(L8]D,)!'1LBT,,
MB7PD!(D$).C^T/__B<>+1@R+&/9#"01T?HM##(E$)`BAH%$%"(E\)`R+`,<$
M)(3(!`B)1"0$Z"_2__^-M"8`````H:!1!0B+.(M&#(L8H4A!!0B)!"3HC]/_
M_XGZB=CHEN?__^F*_O__H4A!!0B)!"3H=-/__\=$)`P"````QT0D"`````")
M7"0$B00DZ*C0___I:?___Z%(004(B00DZ$;3___'1"0,`@```,=$)`@`````
MB5PD!(D$).AZT/__Z5?____'!"1@R`0(Z)G1__^)1"0,H:!1!0B)7"0(BP#'
M!"2LR`0(B40D!.AZT?__C78`C;PG`````%93@^P4BW0D((DT).@?[/__#[8(
MA,ET3XU0`8G#ZPN0#[8*@\(!A,ET$8#Y+W7Q#[8*B=.#P@&$R77OZ'#N__^%
MP'0=A?9T&8`^`'04QT0D!%/'!`B)'"3HL\[__SG8=`J#Q!1;7L.)P^O0@\04
MB?!;7NDYX___B?:-O"<`````@^P<H4A!!0B)!"3H8-+__\=$)`3_____B00D
MZ,#/__^A2$$%"(D$).A#TO__QT0D"`````#'1"0$8*8$"(D$).C[T?__@\0<
MPV:09I!FD)!3Z(K4__^!PPI[``"#[!B+@R`!``")1"0,BT0D*(E$)`B+1"0D
MB40D!(M$)"")!"3H:\___X/$&%O#9I!FD&:055<Q_U93Z$74__^!P\5Z``"#
M[!R+;"0PC;/,_O__Z*G-__^-@\C^__\IQL'^`H7V=">-M@````"+1"0XB2PD
MB40D"(M$)#2)1"0$_Y2[R/[__X/'`3GW==^#Q!Q;7E]=P^L-D)"0D)"0D)"0
MD)"0D//#9I!3@^P(Z-/3__^!PU-Z``"#Q`A;PP,````!``(`)7,O)7,`+W!R
M;V,O<V5L9B]E>&4`<&5R;'AS:2YC`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO
M861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E<P`N`%!!4E]4
M14U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]0
M5`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!
M3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]!4D=#`%!!4E]!4D=67S``4$%2
M7T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!
M4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!,
M24)0051(`$193$1?3$E"4D%265]0051(`%-(3$E"7U!!5$@`55-%4@!365-4
M14T`+W1M<`!414U01$E2`%1-4`!54T523D%-10`E,#)X`'!A<BT`)7,E<R5S
M)7,`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E
M<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;``M90`M+0``7U]%3E9?4$%27T-,
M14%.7U\@("`@("`@("`@("`@("``````)7,Z(&-R96%T:6]N(&]F('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``56YA8FQE('1O(&-R
M96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&5X96-U=&EO;B!O9B`E<R!F
M86EL960@*&5R<FYO/25I*0H``"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A
M8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````(R$O
M=7-R+V)I;B]P97)L"F5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@
M)'LQ*R(D0")])PH@("`@:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE
M('-H96QL"@IP86-K86=E(%]?<&%R7W!L.PH*(R`M+2T@5&AI<R!S8W)I<'0@
M;75S="!N;W0@=7-E(&%N>2!M;V1U;&5S(&%T(&-O;7!I;&4@=&EM92`M+2T*
M(R!U<V4@<W1R:6-T.PH*(VQI;F4@,34X"@IM>2`H)'!A<E]T96UP+"`D<')O
M9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@
M>PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(&UY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PH@("`@
M;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PH@("`@
M1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@
M=6YL:6YK('TL("1P87)?=&5M<"D["B`@("!R;61I<B`D<&%R7W1E;7`["B`@
M("`C($1O;B=T(')E;6]V92!T;W!D:7(@8F5C875S92!T:&ES(&-A=7-E<R!A
M(')A8V4@=VET:"!O=&AE<B!A<'!S"B`@("`C('1H870@87)E('1R>6EN9R!T
M;R!S=&%R="X*"B`@("!I9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7
M:6XS,B<I('L*("`@("`@("`C(%-O;65T:&EN9R!W96YT('=R;VYG('5N;&EN
M:VEN9R!T:&4@=&5M<&]R87)Y(&1I<F5C=&]R>2X@(%1H:7,*("`@("`@("`C
M('1Y<&EC86QL>2!H87!P96YS(&]N('!L871F;W)M<R!T:&%T(&1I<V%L;&]W
M('5N;&EN:VEN9R!S:&%R960*("`@("`@("`C(&QI8G)A<FEE<R!A;F0@97AE
M8W5T86)L97,@=&AA="!A<F4@:6X@=7-E+B!5;FQI;FL@=VET:"!A(&)A8VMG
M<F]U;F0*("`@("`@("`C('-H96QL(&-O;6UA;F0@<V\@=&AE(&9I;&5S(&%R
M92!N;R!L;VYG97(@:6X@=7-E(&)Y('1H:7,@<')O8V5S<RX*("`@("`@("`C
M($1O;B=T(&1O(&%N>71H:6YG(&]N(%=I;F1O=W,@8F5C875S92!O=7(@<&%R
M96YT('!R;V-E<W,@=VEL;`H@("`@("`@(",@=&%K92!C87)E(&]F(&-L96%N
M:6YG('1H:6YG<R!U<"X*"B`@("`@("`@;7D@)'1M<"`](&YE=R!&:6QE.CI4
M96UP*`H@("`@("`@("`@("!414U03$%412`]/B`G=&UP6%A86%@G+`H@("`@
M("`@("`@("!$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I
M<BDL"B`@("`@("`@("`@(%-51D9)6"`]/B`G+F-M9"<L"B`@("`@("`@("`@
M(%5.3$E.2R`]/B`P+`H@("`@("`@("D["@H@("`@("`@('!R:6YT("1T;7`@
M(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PH@("!R
M;2`M<F8@)R1P87)?=&5M<"<*("`@:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=
M.R!T:&5N"B`@("`@("!B<F5A:PH@("!F:0H@("!S;&5E<"`Q"B`@('@]8&5X
M<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*
M(CL*("`@("`@("`@("`@8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*("`@
M("`@("!M>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@
M,CXF,2`F)SL*("`@("`@("!C;&]S92`D=&UP.PH@("`@("`@('-Y<W1E;2@D
M8VUD*3L*("`@("`@("!O=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C
M97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0H@("`@("`@("`@("`@+B`D=&UP
M+3YF:6QE;F%M92D["B`@("!]"GT@?0H*0D5'24X@>PH@("`@26YT97)N86QS
M.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/
M5#L*"B`@("!E=F%L('L*"E]P87)?:6YI=%]E;G8H*3L*"FEF("AE>&ES=',@
M)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*("`@
M($!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[
M4$%27T%21T-]("T@,2D["B`@("`D,"`]("1%3E9[4$%27T%21U9?,'T["GT*
M96QS92!["B`@("!F;W(@*&ME>7,@)45.5BD@>PH@("`@("`@(&1E;&5T92`D
M14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["B`@("!]"GT*"FUY("1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["@HC(&9I>"`D<')O9VYA;64@:68@:6YV;VME
M9"!F<F]M(%!!5$@*;7D@)4-O;F9I9R`]("@*("`@('!A=&A?<V5P("`@(#T^
M("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`H@("`@7V5X92`@("`@
M("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE
M)R`Z("<G*2P*("`@(%]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/
M4S(O(#\@)UQ<)R`Z("<O)RDL"BD["@I?<V5T7W!R;V=N86UE*"D["E]S971?
M<&%R7W1E;7`H*3L*"B,@36%G:6,@<W1R:6YG(&-H96-K:6YG(&%N9"!E>'1R
M86-T:6YG(&)U;F1L960@;6]D=6QE<R![>WL*;7D@*"1S=&%R=%]P;W,L("1D
M871A7W!O<RD["GL*("`@(&QO8V%L("1324=[7U]705).7U]](#T@<W5B('M]
M.PH*("`@(",@0VAE8VL@9FEL92!T>7!E+"!G970@<W1A<G0@;V8@9&%T82!S
M96-T:6]N('M[>PH@("`@;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA
M<W0["B`@("!B:6YM;V1E*%]&2"D["@H@("`@;7D@)&)U9CL*("`@('-E96L@
M7T9(+"`M."P@,CL*("`@(')E860@7T9(+"`D8G5F+"`X.PH@("`@;&%S="!U
M;FQE<W,@)&)U9B!E<2`B7&Y005(N<&U<;B(["@H@("`@<V5E:R!?1D@L("TQ
M,BP@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@<V5E:R!?1D@L("TQ
M,B`M('5N<&%C:R@B3B(L("1B=68I+"`R.PH@("`@<F5A9"!?1D@L("1B=68L
M(#0["@H@("`@)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["B`@("`C('U]
M?0H*("`@(",@17AT<F%C=&EN9R!E86-H(&9I;&4@:6YT;R!M96UO<GD@>WM[
M"B`@("!M>2`E<F5Q=6ER95]L:7-T.PH@("`@=VAI;&4@*"1B=68@97$@(D9)
M3$4B*2!["B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!M>2`D
M9G5L;&YA;64@/2`D8G5F.PH@("`@("`@(&]U=',H<7$H56YP86-K:6YG(&9I
M;&4@(B1F=6QL;F%M92(N+BXI*3L*("`@("`@("!M>2`D8W)C(#T@*"`D9G5L
M;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PH@
M("`@("`@(&UY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0[
M"B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*
M("`@("`@("!I9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP
M;7QP;'QI>'QA;"DD+VDI('L*("`@("`@("`@("`@;7D@*"1O=70L("1F:6QE
M;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD["B`@("`@("`@("`@(&EF
M("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@
M("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("`@("`@
M8VQO<V4@)&]U=#L*("`@("`@("`@("`@("`@(&-H;6]D(#`W-34L("1F:6QE
M;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B`@("`@("`@("`@
M("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M
M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>
M+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PH@("`@
M("`@("`@("`C('-H;W5L9"!B92!M;W9E9"!T;R!?=&5M<&9I;&4H*0H@("`@
M("`@("`@("!M>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N
M86UE)&5X="(["B`@("`@("`@("`@(&]U=',H(E-(3$E".B`D9FEL96YA;65<
M;B(I.PH@("`@("`@("`@("!O<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE
M(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@
M("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("!C;&]S92`D;W5T
M.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)')E<75I
M<F5?;&ES='LD9G5L;&YA;65](#T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ
M.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["B`@("`@("`@("`@("`@("!B
M=68@/3X@)&)U9BP*("`@("`@("`@("`@("`@(&-R8R`]/B`D8W)C+`H@("`@
M("`@("`@("`@("`@;F%M92`]/B`D9G5L;&YA;64L"B`@("`@("`@("`@('T[
M"B`@("`@("`@?0H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@?0H@
M("`@(R!]?7T*"B`@("!L;V-A;"!`24Y#(#T@*'-U8B!["B`@("`@("`@;7D@
M*"1S96QF+"`D;6]D=6QE*2`]($!?.PH*("`@("`@("!R971U<FX@:68@<F5F
M("1M;V1U;&4@;W(@(21M;V1U;&4["@H@("`@("`@(&UY("1F:6QE;F%M92`]
M(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*("`@("`@
M("`@("`@;7D@)&ME>3L*("`@("`@("`@("`@9F]R96%C:"`H:V5Y<R`E<F5Q
M=6ER95]L:7-T*2!["B`@("`@("`@("`@("`@("!N97AT('5N;&5S<R`O7%$D
M;6]D=6QE7$4D+SL*("`@("`@("`@("`@("`@("1K97D@/2`D7SL@;&%S=#L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES
M='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PH@("`@("`@('T@;W(@<F5T=7)N
M.PH*("`@("`@("`D24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE
M+R1M;V1U;&4B.PH*("`@("`@("!I9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D
M969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PH@("`@("`@("`@("!M>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PH@("`@("`@("`@
M("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@('!R:6YT("1F:"`D9FEL96YA
M;64M/GMB=69].PH@("`@("`@("`@("!S965K*"1F:"P@,"P@,"D["B`@("`@
M("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@
M("`@("`@("`@("!M>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG
M+"`D9FEL96YA;64M/GMC<F-]*3L*("`@("`@("`@("`@:68@*"1O=70I('L*
M("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@
M("!P<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@("`@
M("!C;&]S92`D;W5T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&]P96X@
M;7D@)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN
M;6]D92@D9F@I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*
M"B`@("`@("`@9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I
M;F0@)&UO9'5L92%<;B(["B`@("!]+"!`24Y#*3L*"B`@("`C($YO=R!L;V%D
M(&%L;"!B=6YD;&5D(&9I;&5S('M[>PH*("`@(",@:6YI=&EA;&EZ92!S:&%R
M960@;V)J96-T('!R;V-E<W-I;F<*("`@(')E<75I<F4@6%-,;V%D97(["B`@
M("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E($-A<G`Z.DAE879Y
M.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H@("`@(R!N;W<@;&5T)W,@=')Y(&=E
M='1I;F<@:&5L<&5R(&UO9'5L97,@9G)O;2!W:71H:6X*("`@(')E<75I<F4@
M24\Z.D9I;&4["@H@("`@(R!L;V%D(')E<W0@;V8@=&AE(&=R;W5P(&EN"B`@
M("!W:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L
M:7-T*5LP72D@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?
M1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@=6YL97-S("@D
M24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["B`@
M("`@("`@("`@(",@<F5Q=6ER92!M;V1U;&5S+"!D;R!O=&AE<B!E>&5C=71A
M8FQE(&9I;&5S"B`@("`@("`@("`@(&EF("@D9FEL96YA;64@/7X@+UPN<&UC
M/R0O:2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER92`D9FEL96YA;64["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@
M("`C(%-K:7`@06-T:79E4W1A=&4G<R!S:71E8W5S=&]M:7IE+G!L(&9I;&4Z
M"B`@("`@("`@("`@("`@("!D;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M
M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65]
M.PH@("`@?0H*("`@(",@?7U]"@H@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B
M4$M<,#`S7#`P-"(["B`@("`D<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[
M"GT*(R!]?7T*"B,@07)G=6UE;G0@<')O8V5S<VEN9R![>WL*;7D@0'!A<E]A
M<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D[
M"@ID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D55
M4T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*"B1Q=6EE="`](#`@=6YL
M97-S("1%3E9[4$%27T1%0E5'?3L*(R!$;VXG="!S=V%L;&]W(&%R9W5M96YT
M<R!F;W(@8V]M<&EL960@97AE8W5T86)L97,@=VET:&]U="`M+7!A<BUO<'1I
M;VYS"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P
M=&EO;G,G("8F('-H:69T*2D@>PH@("`@;7D@)61I<W1?8VUD(#T@<7<H"B`@
M("`@("`@<"`@(&)L:6)?=&]?<&%R"B`@("`@("`@:2`@(&EN<W1A;&Q?<&%R
M"B`@("`@("`@=2`@('5N:6YS=&%L;%]P87(*("`@("`@("!S("`@<VEG;E]P
M87(*("`@("`@("!V("`@=F5R:69Y7W!A<@H@("`@*3L*"B`@("`C(&EF('1H
M92!A<'`@:7,@:6YV;VME9"!A<R`B87!P;F%M92`M+7!A<BUO<'1I;VYS("TM
M<F5U<V4@4%)/1U)!32!`4%)/1U]!4D=6(BP*("`@(",@=7-E('1H92!A<'`@
M=&\@<G5N('1H92!G:79E;B!P97)L(&-O9&4@:6YS=&5A9"!O9B!A;GET:&EN
M9R!F<F]M('1H90H@("`@(R!A<'`@:71S96QF("AB=70@<W1I;&P@<V5T('5P
M('1H92!N;W)M86P@87!P(&5N=FER;VYM96YT(&%N9"!`24Y#*0H@("`@:68@
M*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*("`@("`@("!S
M:&EF="!`05)'5CL*("`@("`@("`D14Y6>U!!4E]!4%!?4D554T5](#T@<VAI
M9G0@0$%21U8["B`@("!]"B`@("!E;'-E('L@(R!N;W)M86P@<&%R;"!B96AA
M=FEO=7(*"B`@("`@("`@;7D@0&%D9%]T;U]I;F,["B`@("`@("`@=VAI;&4@
M*$!!4D=6*2!["B`@("`@("`@("`@("1!4D=66S!=(#U^("]>+2A;04E-3T),
M8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["@H@("`@("`@("`@("!I9B`H)#$@
M97$@)TDG*2!["B`@("`@("`@("`@("`@("!P=7-H($!A9&1?=&]?:6YC+"`D
M,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)TTG
M*2!["B`@("`@("`@("`@("`@("!E=F%L(")U<V4@)#(B.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G02<I('L*("`@("`@("`@
M("`@("`@('5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!E;'-I9B`H)#$@97$@)T\G*2!["B`@("`@("`@("`@("`@
M("`D;W5T(#T@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@
M*"0Q(&5Q("=B)RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]("=S:71E
M)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T(G
M*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE(#T@)V%L;"<["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=Q)RD@>PH@("`@("`@
M("`@("`@("`@)'%U:65T(#T@,3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!E;'-I9B`H)#$@97$@)TPG*2!["B`@("`@("`@("`@("`@("!O<&5N("1L
M;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@
M)"$B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G
M5"<I('L*("`@("`@("`@("`@("`@("1C86-H95]N86UE(#T@)#(["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@('-H:69T*$!!4D=6*3L*"B`@("`@("`@
M("`@(&EF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PH@("`@("`@("`@
M("`@("`@9&5L971E("1%3E9[)U!!4E]414U0)WT["B`@("`@("`@("`@("`@
M("!I;FET7VEN8R@I.PH@("`@("`@("`@("`@("`@<F5Q=6ER92!005(Z.D1I
M<W0["B`@("`@("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N
M;&5S<R!`05)'5CL*("`@("`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"1?*2!F;W(@0$%21U8["B`@("`@("`@("`@("`@("!E>&ET.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!U;G-H:69T($!)3D,L($!A
M9&1?=&]?:6YC.PH@("`@?0I]"@HC(%A86"`M+2!A9&0@+2UP87(M9&5B=6<@
M<W5P<&]R="$*"B,@?7U]"@HC($]U='!U="!M;V1E("@M3RD@:&%N9&QI;F<@
M>WM["FEF("@D;W5T*2!["B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W
M9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@
M("!R97%U:7)E($E/.CI&:6QE.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ
M6FEP.PH@("`@?0H*("`@(&UY("1P87(@/2!S:&EF="A`05)'5BD["B`@("!M
M>2`D>FEP.PH*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E
M;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R
M)SH@)"$B.PH@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("!B;&5S<R@D
M9F@L("=)3SHZ1FEL92<I.PH*("`@("`@("`D>FEP(#T@07)C:&EV93HZ6FEP
M+3YN97<["B`@("`@("`@*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0H@("`@("`@("`@
M("!O<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["B`@("!]"@H*("`@
M(&UY("5E;G8@/2!D;R!["B`@("`@("`@:68@*"1Z:7`@86YD(&UY("1M971A
M(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*("`@("`@("`@("`@
M)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B`@("`@("`@("`@("1M971A(#U^
M(',O7EQ3+BHO+VUS.PH@("`@("`@("`@("`D;65T82`]?B`O7B`@*%M>.ETK
M*3H@*"XK*20O;6<["B`@("`@("`@?0H@("`@?3L*"B`@("`C($]P96X@:6YP
M=70@86YD(&]U='!U="!F:6QE<R![>WL*("`@(&QO8V%L("0O(#T@7#0["@H@
M("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@4$%2+"`G/"<L
M("1P87(@;W(@9&EE("(D(3H@)'!A<B(["B`@("`@("`@8FEN;6]D92A005(I
M.PH@("`@("`@(&1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S
M(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*("`@('T*"B`@("!#<F5A=&50871H
M*"1O=70I(#L*("`@(`H@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*("`@
M("`@("`D;W5T+`H@("`@("`@($E/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ
M1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"B`@("`@
M("`@,#<W-RP*("`@("D@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH*
M("`@("0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U
M;F1E9CL*("`@('-E96L@7T9(+"`P+"`P.PH@("`@;7D@)&QO861E<B`]('-C
M86QA<B`\7T9(/CL*("`@(&EF("@A)$5.5GM005)?5D520D%424U](&%N9"`D
M;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PH@("`@("`@(')E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@("`@(%!!4CHZ1FEL=&5R.CI0
M;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"B`@("!]"B`@("!F
M;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["B`@("`@("`@;7D@
M)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*("`@("`@("`D=F%L(#T@979A
M;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*("`@("`@("!M>2`D;6%G:6,@
M/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["B`@("`@("`@;7D@
M)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*("`@("`@("`D
M;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B`@("`@("`@("`@("1M86=I8R`N
M("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0H@
M("`@("`@('UE9SL*("`@('T*("`@("1F:"T^<')I;G0H)&QO861E<BD["B`@
M("`D+R`]('5N9&5F.PH@("`@(R!]?7T*"B`@("`C(%=R:71E(&)U;F1L960@
M;6]D=6QE<R![>WL*("`@(&EF("@D8G5N9&QE*2!["B`@("`@("`@<F5Q=6ER
M92!005(Z.DAE879Y.PH@("`@("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*("`@("`@("!I;FET7VEN8R@I.PH*("`@("`@("!R97%U:7)E
M7VUO9'5L97,H*3L*"B`@("`@("`@;7D@0&EN8R`]('-O<G0@>PH@("`@("`@
M("`@("!L96YG=&@H)&(I(#P]/B!L96YG=&@H)&$I"B`@("`@("`@?2!G<F5P
M('L*("`@("`@("`@("`@(2]"4T1004XO"B`@("`@("`@?2!G<F5P('L*("`@
M("`@("`@("`@*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@H@("`@("`@("`@("`H
M)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`H@("`@("`@
M("`@("`@)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*("`@
M("`@("!]($!)3D,["@H@("`@("`@(",@1FEL92!E>&ES=',@=&5S="!A9&1E
M9"!T;R!F:7@@4E0@(S0Q-SDP.@H@("`@("`@(",@1G5N;GDL(&YO;BUE>&ES
M=&EN9R!E;G1R>2!I;B!?/"XN+BYA=71O+T-O;7!R97-S+U)A=R]:;&EB+V%U
M=&]S<&QI="YI>"X*("`@("`@("`C(%1H:7,@:7,@82!B86YD+6%I9"!F:7@@
M=VET:"!N;R!D965P97(@9W)A<W`@;V8@=&AE(&ES<W5E+@H@("`@("`@(",@
M4V]M96)O9'D@<&QE87-E(&=O('1H<F]U9V@@=&AE('!A:6X@;V8@=6YD97)S
M=&%N9&EN9R!W:&%T)W,@:&%P<&5N:6YG+`H@("`@("`@(",@22!F86EL960N
M("TM(%-T969F96X*("`@("`@("!M>2`E9FEL97,["B`@("`@("`@+UY?/"@N
M*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH[
M"B`@("`@("`@)&9I;&5S>R1??2LK(&9O<B!V86QU97,@)4E.0SL*"B`@("`@
M("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["B`@
M("`@("`@;7D@)7=R:71T96X["@H@("`@("`@(&9O<F5A8V@@*'-O<G0@:V5Y
M<R`E9FEL97,I('L*("`@("`@("`@("`@;7D@*"1N86UE+"`D9FEL92D["@H@
M("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I;F,I('L*("`@("`@("`@
M("`@("`@(&EF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]
M*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2`D7SL*("`@("`@("`@
M("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PH@
M("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD[
M"B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>
M0V-=*5Q:(2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AM>2`D<F5F(#T@
M)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["B`@("`@
M("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@(&5L<VEF("@M9B`B)&1I<B\D,2(I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H(B1D
M:7(O)#$B+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1N86UE
M(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["B`@("`@("`@("`@(&YE>'0@
M:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O
M.PH@("`@("`@("`@("!O=71S*"!J;VEN("(B+`H@("`@("`@("`@("`@("`@
M<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F
M:6QE+`H@("`@("`@("`@("`@("`@<7$H(BXN+BD*("`@("`@("`@("`@*3L*
M"B`@("`@("`@("`@(&UY("1C;VYT96YT.PH@("`@("`@("`@("!I9B`H<F5F
M*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D9FEL92T^
M>V)U9GT["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@
M("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG
M="!O<&5N("1F:6QE.B`D(2(["B`@("`@("`@("`@("`@("!B:6YM;V1E*$9)
M3$4I.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`\1DE,13X["B`@("`@
M("`@("`@("`@("!C;&]S92!&24Q%.PH*("`@("`@("`@("`@("`@(%!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE
M*0H@("`@("`@("`@("`@("`@("`@(&EF("$D14Y6>U!!4E]615)"051)37T@
M86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*"B`@("`@("`@("`@
M("`@("!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD
M8V]N=&5N="P@)&9I;&4L("1N86UE*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*("`@("`@("`@
M("`@)&9H+3YP<FEN="@B1DE,12(I.PH@("`@("`@("`@("`D9F@M/G!R:6YT
M*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PH@("`@("`@("`@("`D
M9F@M/G!R:6YT*'-P<FEN=&8H"B`@("`@("`@("`@("`@("`B)3`X>"\E<R(L
M($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64*
M("`@("`@("`@("`@*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G
M3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN
M="@D8V]N=&5N="D["B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*"B`@("`C
M($YO=R!W<FET92!O=70@=&AE(%!!4B!A;F0@;6%G:6,@<W1R:6YG<R![>WL*
M("`@("1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*"B`@
M("`D8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["B`@
M("!I9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T
M*2E;.5TI('L*("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("!\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^
M;F5W('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-
M1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@(R!7;W)K87)O=6YD
M(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@
M(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)
M3TX@?2!\?"`P.PH@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G
M(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@)&-T
M>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("!]"B`@
M("`@("`@96QS92!["B`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY
M("1F:"P@(CPD;W5T(BDI('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H
M*3L*("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@
M("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S
M="`Z("1M=&EM93L*("`@('T*("`@("1C86-H95]N86UE("X](")<,"(@>"`H
M-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PH@("`@)&-A8VAE7VYA;64@+CT@
M(D-!0TA%(CL*("`@("1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PH@("`@)&9H
M+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I
M*2D["B`@("`D9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B`@("`D9F@M/F-L
M;W-E.PH@("`@8VAM;V0@,#<U-2P@)&]U=#L*("`@(",@?7U]"@H@("`@97AI
M=#L*?0HC('U]?0H*(R!0<F5P87)E("1P<F]G;F%M92!I;G1O(%!!4B!F:6QE
M(&-A8VAE('M[>PI["B`@("!L87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P
M;W,["@H@("`@7V9I>%]P<F]G;F%M92@I.PH*("`@(",@3F]W(&QO860@=&AE
M(%!!4B!F:6QE(&%N9"!P=70@:70@:6YT;R!005(Z.DQI8D-A8VAE('M[>PH@
M("`@<F5Q=6ER92!005(["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["@H*("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@
M/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I
M<F4@1FEL93HZ1FEN9#L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*
M("`@('T*("`@(&UY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@(&UY
M("1F:"`]($E/.CI&:6QE+3YN97<["B`@("`D9F@M/F9D;W!E;BAF:6QE;F\H
M7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B`@("`D>FEP+3YR96%D1G)O
M;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["@H@("`@<'5S:"!`4$%2.CI,:6)#
M86-H92P@)'II<#L*("`@("1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D
M>FEP.PH*("`@("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["B`@("!O=71S
M*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*"B`@
M("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S
M970@870@=&AI<R!P;VEN="$*("`@("`@("!F;W)E86-H(&UY("1M96UB97(@
M*"`D>FEP+3YM96UB97)S("D@>PH@("`@("`@("`@("!N97AT(&EF("1M96UB
M97(M/FES1&ER96-T;W)Y.PH@("`@("`@("`@("!M>2`D;65M8F5R7VYA;64@
M/2`D;65M8F5R+3YF:6QE3F%M93L*("`@("`@("`@("`@;F5X="!U;FQE<W,@
M)&UE;6)E<E]N86UE(#U^(&U["B`@("`@("`@("`@("`@("!>"B`@("`@("`@
M("`@("`@("`O/W-H;&EB+PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ
M0V]N9FEG>W9E<G-I;VY]+RD_"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG
M.CI#;VYF:6=[87)C:&YA;65]+RD_"B`@("`@("`@("`@("`@("`H6UXO72LI
M"B`@("`@("`@("`@("`@("`D"B`@("`@("`@("`@('UX.PH@("`@("`@("`@
M("!M>2`D97AT<F%C=%]N86UE(#T@)#$["B`@("`@("`@("`@(&UY("1D97-T
M7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D
M97AT<F%C=%]N86UE*3L*("`@("`@("`@("`@:68@*"UF("1D97-T7VYA;64@
M)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*("`@
M("`@("`@("`@("`@(&]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@
M<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!O=71S*'%Q*$5X
M=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B`@
M("`@("`@("`@("`@("`D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D["B`@("`@("`@("`@("`@("!C:&UO9"@P-34U+"`D9&5S=%]N
M86UE*2!I9B`D7D\@97$@(FAP=7@B.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@?0H@("`@(R!]?7T*?0HC('U]?0H*(R!)9B!T:&5R92=S(&YO(&UA
M:6XN<&P@=&\@<G5N+"!S:&]W('5S86=E('M[>PIU;FQE<W,@*"1005(Z.DQI
M8D-A8VAE>R1P<F]G;F%M97TI('L*("`@(&1I92`\/"`B+B(@=6YL97-S($!!
M4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO
M9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B`@("`@("`D,"!;
M("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B`@("`D14Y6>U!!4E]0
M4D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0HC
M('U]?0H*<W5B($-R96%T95!A=&@@>PH@("`@;7D@*"1N86UE*2`]($!?.PH@
M("`@"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@;7D@*"1B87-E
M;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S
M92@D;F%M92P@*"=<+BXJ)RDI.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.E!A
M=&@["B`@("`*("`@($9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S
M*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*"G-U8B!R
M97%U:7)E7VUO9'5L97,@>PH@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@
M7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*"B`@("!R97%U:7)E(&QI
M8CL*("`@(')E<75I<F4@1'EN84QO861E<CL*("`@(')E<75I<F4@:6YT96=E
M<CL*("`@(')E<75I<F4@<W1R:6-T.PH@("`@<F5Q=6ER92!W87)N:6YG<SL*
M("`@(')E<75I<F4@=F%R<SL*("`@(')E<75I<F4@0V%R<#L*("`@(')E<75I
M<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5R<FYO.PH@("`@<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.PH@("`@
M<F5Q=6ER92!&8VYT;#L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E
M<75I<F4@1FEL93HZ4W!E8SL*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R
M97%U:7)E($-O;F9I9SL*("`@(')E<75I<F4@24\Z.DAA;F1L93L*("`@(')E
M<75I<F4@24\Z.D9I;&4["B`@("!R97%U:7)E($-O;7!R97-S.CI:;&EB.PH@
M("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!R97%U:7)E(%!!4CL*("`@
M(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@4$%2.CI$:7-T.PH@
M("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("!R97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["B`@("!R97%U:7)E(&%T=')I
M8G5T97,["B`@("!E=F%L('L@<F5Q=6ER92!#=V0@?3L*("`@(&5V86P@>R!R
M97%U:7)E(%=I;C,R('T["B`@("!E=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T
M:6P@?3L*("`@(&5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S
M="!].PH@("`@979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U
M<F4@?3L*("`@(&5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L
M24\Z.G-C86QA<B!].PI]"@HC(%1H92!#('9E<G-I;VX@;V8@=&AI<R!C;V1E
M(&%P<&5A<G,@:6X@;7EL9'(O;6MT;7!D:7(N8PHC(%1H:7,@8V]D92!A;'-O
M(&QI=F5S(&EN(%!!4CHZ4V5T=7!496UP(&%S('-E=%]P87)?=&5M<%]E;G8A
M"G-U8B!?<V5T7W!A<E]T96UP('L*("`@(&EF("AD969I;F5D("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*("`@("`@
M("`D<&%R7W1E;7`@/2`D,3L*("`@("`@("!R971U<FX["B`@("!]"@H@("`@
M9F]R96%C:"!M>2`D<&%T:"`H"B`@("`@("`@*&UA<"`D14Y6>R1??2P@<7<H
M(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"B`@("`@
M("`@<7<H($,Z7%Q414U0("]T;7`@+B`I"B`@("`I('L*("`@("`@("!N97AT
M('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A
M=&@["B`@("`@("`@;7D@)'5S97)N86UE.PH@("`@("`@(&UY("1P=W5I9#L*
M("`@("`@("`C(&1O97,@;F]T('=O<FL@979E<GEW:&5R93H*("`@("`@("!E
M=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT[
M"@H@("`@("`@(&EF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2![
M"B`@("`@("`@("`@("1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PH@
M("`@("`@('T*("`@("`@("!E;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*("`@
M("`@("`@("`@)'5S97)N86UE(#T@)'!W=6ED.PH@("`@("`@('T*("`@("`@
M("!E;'-E('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)$5.5GM54T523D%-
M17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*("`@("`@("!]"B`@("`@
M("`@)'5S97)N86UE(#U^(',O7%<O7R]G.PH*("`@("`@("!M>2`D<W1M<&1I
M<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D
M=7-E<FYA;64I.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@
M("`@(&EF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A
M="@D<')O9VYA;64I*5LY72D@>PH@("`@("`@("`@("!O<&5N("AM>2`D9F@L
M("(\(BX@)'!R;V=N86UE*3L*("`@("`@("`@("`@<V5E:R`D9F@L("TQ."P@
M,CL*("`@("`@("`@("`@<WES<F5A9"`D9F@L(&UY("1B=68L(#8["B`@("`@
M("`@("`@(&EF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PH@("`@("`@("`@("`@
M("`@<V5E:R`D9F@L("TU."P@,CL*("`@("`@("`@("`@("`@('-Y<W)E860@
M)&9H+"`D8G5F+"`T,3L*("`@("`@("`@("`@("`@("1B=68@/7X@<R]<,"\O
M9SL*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UC86-H92TB("X@)&)U9CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-E('L*("`@("`@("`@("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@
M("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$
M:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A
M;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*
M"B`@("`@("`@("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E
M<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@("`@("`@("!M>2`D<VAA
M7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@
M,#L*("`@("`@("`@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G
M(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@("`@
M("`@("`D8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\
M)'!R;V=N86UE(BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@8FEN;6]D
M92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE
M*"1F:"D["B`@("`@("`@("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB
M("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("!]"B`@
M("`@("`@96QS92!["B`@("`@("`@("`@("1%3E9[4$%27T-,14%.?2`](#$[
M"B`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP
M+20D(CL*("`@("`@("!]"@H@("`@("`@("1%3E9[4$%27U1%35!](#T@)'-T
M;7!D:7(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@
M;&%S=#L*("`@('T*"B`@("`D<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]4
M14U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"@IS=6(@7W1E
M;7!F:6QE('L*("`@(&UY("@D97AT+"`D8W)C*2`]($!?.PH@("`@;7D@*"1F
M:"P@)&9I;&5N86UE*3L*"B`@("`D9FEL96YA;64@/2`B)'!A<E]T96UP+R1C
M<F,D97AT(CL*"B`@("!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("`@("`@
M=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL96YA;64["B`@("`@("`@<'5S
M:"!`=&UP9FEL92P@)&9I;&5N86UE.PH@("`@?0H@("`@96QS92!["B`@("`@
M("`@<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE
M*3L*("`@('T*"B`@("!O<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE
M("0A.PH@("`@8FEN;6]D92@D9F@I.PH@("`@<F5T=7)N*"1F:"P@)&9I;&5N
M86UE*3L*?0H*(R!S86UE(&-O9&4@;&EV97,@:6X@4$%2.CI3971U<%!R;V=N
M86UE.CIS971?<')O9VYA;64*<W5B(%]S971?<')O9VYA;64@>PH@("`@:68@
M*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'
M3D%-17T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!R;V=N86UE(#T@)#$["B`@
M("!]"@H@("`@)'!R;V=N86UE('Q\/2`D,#L*"B`@("!I9B`H)$5.5GM005)?
M5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X]
M(#`I('L*("`@("`@("`D<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R
M:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["B`@("!]
M"@H@("`@:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N
M86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*("`@("`@("!I9B`H;W!E
M;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["B`@("`@("`@("`@(')E='5R
M;B!I9B`M<R`D9F@["B`@("`@("`@?0H@("`@("`@(&EF("@M<R`B)'!R;V=N
M86UE)$-O;F9I9WM?97AE?2(I('L*("`@("`@("`@("`@)'!R;V=N86UE("X]
M("1#;VYF:6=[7V5X97T["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]
M"B`@("!]"@H@("`@9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG
M>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PH@("`@("`@(&YE>'0@:68@
M97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%
M35!].PH@("`@("`@("1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O
M.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"B`@("`@("`@("`@(&EF
M("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE
M?2(["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"GT*"G-U8B!?9FEX7W!R
M;V=N86UE('L*("`@("0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'
M3D%-17T["B`@("!I9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI(#P@,"D@>PH@("`@("`@("1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(CL*("`@('T*"B`@("`C(%A86"`M(&AA8VL@=&\@;6%K
M92!05T0@=V]R:PH@("`@;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W
M9"D@/R!#=V0Z.F=E=&-W9"@I"B`@("`@("`@("`@("`@("`Z("@H9&5F:6YE
M9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D[
M"B`@("!C:&]M<"@D<'=D*3L*("`@("1P<F]G;F%M92`]?B!S+UXH/SU<+EPN
M/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PH*
M("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0H*<W5B(%]P
M87)?:6YI=%]E;G8@>PH@("`@:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK
M*R`]/2`Q("D@>PH@("`@("`@(')E='5R;CL*("`@('T@96QS92!["B`@("`@
M("`@)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*("`@('T*"B`@("!F;W(@
M*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@
M05)'0R!!4D=67S`@*2`I('L*("`@("`@("!D96QE=&4@)$5.5GLG4$%27R<N
M)%]].PH@("`@?0H@("`@9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"
M54<@+RD@>PH@("`@("`@("1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'
M3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT[
M"B`@("!]"@H@("`@;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?
M7R`@("`@("`@("`@("`@("(["@H@("`@:68@*"1%3E9[4$%27U1%35!]*2![
M"B`@("`@("`@9&5L971E("1%3E9[4$%27T-,14%.?3L*("`@('T*("`@(&5L
M<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*("`@("`@
M("!M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H
M(D-,14%.(BDI.PH@("`@("`@("1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V
M86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["B`@("!]"GT*"G-U8B!O=71S
M('L*("`@(')E='5R;B!I9B`D<75I970["B`@("!I9B`H)&QO9V9H*2!["B`@
M("`@("`@<')I;G0@)&QO9V9H(")`7UQN(CL*("`@('T*("`@(&5L<V4@>PH@
M("`@("`@('!R:6YT(")`7UQN(CL*("`@('T*?0H*<W5B(&EN:71?:6YC('L*
M("`@(')E<75I<F4@0V]N9FEG.PH@("`@<'5S:"!`24Y#+"!G<F5P(&1E9FEN
M960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*("`@("`@("!A<F-H
M;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`H@("`@
M("`@('9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"B`@("`I.PI]"@HC(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*(R!4:&4@;6%I;B!P86-K86=E(&9O
M<B!S8W)I<'0@97AE8W5T:6]N"@IP86-K86=E(&UA:6X["@IR97%U:7)E(%!!
M4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T
M*$!P87)?87)G<RD["@ID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@
M<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y
M7&XI"B`@("!U;FQE<W,@+64@)'!R;V=N86UE.PH*9&\@)'!R;V=N86UE.PI#
M3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I
M.PID:64@)$`@:68@)$`["@I].PH*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]
M"@I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?
M7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["@HQ
M.PH*(VQI;F4@,3`Q,0H*7U]%3D1?7PH``````````````(#____/00$;`SOP
M````'0```'!N__\,`0``P'+__VP%``"@=?__,`$``+"`__]P`0``4('__\0!
M``!@@?__W`$``+"!__\``@``((/__RP"``"0A/__6`(``'"&__^8`@``@(?_
M_\0"```0B/__\`(``%"(__\(`P``L(C__R`#``"@B?__2`,``+")__]<`P``
M<(O__YP#``"@B___L`,``(",___P`P``(([__R`$``!PCO__/`0``*".__]8
M!```P(___Y@$``!PF___W`0``'"?__\<!0``\)___U0%``!`H/__F`4``("@
M__^X!0``\*#___0%```4``````````%Z4@`!?`@!&PP$!(@!```@````'```
M`%QM__]0!`````X(1@X,2@\+=`1X`#\:.RHR)"(\````0````&AT__\)"P``
M`$$."(4"0PX,AP-$#A"&!$$.%(,%1@[L`@/U"@X40<,.$$'&#@Q!QPX(0<4.
M!```4````(`````X?___FP````!!#@B%`D$.#(<#00X0A@1##A2#!4,.0`)6
M"@X40\,.$$'&#@Q!QPX(0<4.!$,+:@X41<,.$$'&#@Q!QPX(0<4.!```%```
M`-0```"$?___$`````!##B!,#@0`(````.P```!\?___4`````!!#@B#`D4.
M(`)(#@A!PPX$````*````!`!``"H?___;0$```!!#@B&`D$.#(,#0PX@`V4!
M#@Q!PPX(0<8.!``H````/`$``.R`__]I`0```$8.L`%)A@17@P6'`X4":0K%
MQ\;##@1!"P```#P```!H`0``,(+__]T!````00X(A0)!#@R'`T,.$(8$0PX4
M@P5%#E`"SPH.%$'##A!!Q@X,0<<."$'%#@1("P`H````J`$``-"#__\$`0``
M`$8.P"!'A@1>AP-)A0)8@P4"A`K%Q\;##@1("R@```#4`0``M(3__XT`````
M00X(@P)%#B!K"@X(0\,.!$0+`E`."$3##@0`%``````"```8A?__-`````!#
M#B!P#@0`%````!@"``!`A?__60````!##C`"50X$)````#`"``"(A?__X0``
M``!&#L!`1X,$888#AP("J`K'QL,.!$(+`!````!8`@``4(;__P4`````````
M/````&P"``!,AO__M0$```!!#@B%`D$.#(<#00X0A@1!#A2#!48.X"`"90H.
M%$'##A!!Q@X,0<<."$'%#@1!"Q````"L`@``S(?__RT`````````/````,`"
M``#HA___V`````!!#@B#`D,.(`)<"@X(0<,.!$<+`DL*#@A&PPX$1PM#"@X(
M0\,.!$$+2PX(0<,.!"P``````P``B(C__Y\!````00X(AP)!#@R&`T,.0`-/
M`0H.#$'&#@A!QPX$0@L``!@````P`P``^(G__T0`````4PX09PH.!$8+```8
M````3`,``"R*__\D`````$,.(%8*#@1'"P``/````&@#``!`BO__$@$```!!
M#@B%`D$.#(<#1@X0A@1!#A2#!4@.<`*$"@X40<,.$$'&#@Q!QPX(0<4.!$<+
M`$````"H`P``((O__Z4+````00X(A0)!#@R'`T$.$(8$00X4@P5&#M""`@.X
M`@H.%$'##A!!Q@X,0<<."$'%#@1""P``/````.P#``",EO__]@,```!!#@B%
M`D$.#(<#00X0A@1!#A2#!4,.,`-;`@H.%$'##A!!Q@X,0<<."$'%#@1""S0`
M```L!```3)K__W<`````00X(A@)!#@R#`T,.(`)?"@X,0<,."$'&#@1!"T<.
M#$/##@A!Q@X$%````&0$``"4FO__20````!##B`"10X$*````'P$``!,;?__
MZ@$```!!#@B%`D(-!4B&`X,$`X,!"L-!QD'%#`0$00L<````J`0``*":__\Z
M`````$$."(,"3@X@:0X(0<,.!#@```#(!```P)K__V$`````00X(A0)!#@R'
M`T,.$(8$00X4@P5.#C`"2`X40<,.$$'&#@Q!QPX(0<4.!!`````$!0``])K_
M_P(`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````@F@0(`)H$"``````!`````0````$``````@```0``
M``P"```!````%P(```$````A`@```0```"\"```!````/`(```$```"+`@``
M#P```/\#```,````_)($"`T```"DQ00(&0```,@^!0@;````!````!H```#,
M/@4('`````0```#U_O]OK($$"`4```"XB00(!@````B#!`@*````C@4```L`
M```0````%0`````````#`````$`%"`(````@`@``%````!$````7````W)`$
M"!$```"LD`0($@```#`````3````"````/[__V\<D`0(____;P(```#P__]O
M1H\$"```````````````````````````````````````````````````````
M``````````````#4/@4(```````````VDP0(1I,$"%:3!`AFDP0(=I,$"(:3
M!`B6DP0(II,$"+:3!`C&DP0(UI,$".:3!`CVDP0(!I0$"!:4!`@FE`0(-I0$
M"$:4!`A6E`0(9I0$"':4!`B&E`0(EI0$"*:4!`BVE`0(QI0$"-:4!`CFE`0(
M]I0$"`:5!`@6E00()I4$"#:5!`A&E00(5I4$"&:5!`AVE00(AI4$"):5!`BF
ME00(MI4$",:5!`C6E00(YI4$"/:5!`@&E@0(%I8$"":6!`@VE@0(1I8$"%:6
M!`AFE@0(=I8$"(:6!`B6E@0(II8$"+:6!`C&E@0(UI8$".:6!`CVE@0(!I<$
M"!:7!`@FEP0(-I<$"$:7!`A6EP0(9I<$"```````````\,@$"/____]'0T,Z
M("A'3E4I(#0N-RXR```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G
M`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R
M`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N<F5L+G!L
M=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H
M7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`+F1Y;F%M:6,`
M+F=O=``N9V]T+G!L=``N9&%T80`N8G-S`"YC;VUM96YT````````````````
M````````````````````````````````````````"P````$````"````5($$
M"%0!```3```````````````!`````````!,````'`````@```&B!!`AH`0``
M(```````````````!``````````A````!P````(```"(@00(B`$``"0`````
M``````````0`````````-````/;__V\"````K($$"*P!``!<`0``!0``````
M```$````!````#X````+`````@````B#!`@(`P``L`8```8````!````!```
M`!````!&`````P````(```"XB00(N`D``(X%``````````````$`````````
M3@```/___V\"````1H\$"$8/``#6````!0`````````"`````@```%L```#^
M__]O`@```!R0!`@<$```D`````8````"````!`````````!J````"0````(`
M``"LD`0(K!```#`````%``````````0````(````<P````D````"````W)`$
M"-P0```@`@``!0````P````$````"````'P````!````!@```/R2!`C\$@``
M(P``````````````!`````````!W`````0````8````@DP0((!,``%`$````
M`````````!`````$````@@````$````&````<)<$"'`7```T+@``````````
M```0`````````(@````!````!@```*3%!`BD10``%```````````````!```
M``````".`````0````(```"XQ00(N$4``/A>``````````````@`````````
ME@````$````"````L"0%"+"D``#T```````````````$`````````*0````!
M`````@```*0E!0BDI0``&`4`````````````!`````````"N````#@````,`
M``#(/@4(R*X```0```````````````0`````````N@````\````#````S#X%
M",RN```$```````````````$`````````,8````!`````P```-`^!0C0K@``
M!```````````````!`````````#+````!@````,```#4/@4(U*X``"@!```&
M``````````0````(````U`````$````#````_#\%"/RO```$````````````
M```$````!````-D````!`````P````!`!0@`L```'`$`````````````!```
M``0```#B`````0````,````<004('+$``!````````````````0`````````
MZ`````@````#````0$$%""RQ``!P$``````````````@`````````.T````!
M````,``````````LL0``$0```````````````0````$````!`````P``````
>````````/;$``/8```````````````$`````````
